--------------------------------------------------------------------------------
-- StrUtilsLib 1.0.1 -- by Ivan Llanas -----------------------------------------
--------------------------------------------------------------------------------
--[[
function StringHash        (text)
function IntToStrThousands (value)
function MoneyString       (money, graphic, shorten_threshold)
function MoneyStringRaw    (money, shorten_threshold)
]]--
--------------------------------------------------------------------------------

--------------------------------------------------------------------------------
function Print (text)

   DEFAULT_CHAT_FRAME:AddMessage (text);
end;

--------------------------------------------------------------------------------
function PPrint (text, prefix)

   local s = text;
   if prefix then s = prefix.."|r> "..s  end;
   DEFAULT_CHAT_FRAME:AddMessage (s);
end;

--------------------------------------------------------------------------------
function StringHash (text)

   local counter = 1;
   local len = string.len(text);
   
   for i = 1, len, 3 do
      counter = math.fmod(counter*8161, 4294967279) +  -- 2^32 - 17: Prime!
                          (string.byte(text,i)*16776193) +
                          ((string.byte(text,i+1) or (len-i+256))*8372226) +
                          ((string.byte(text,i+2) or (len-i+256))*3932164)
   end
   return math.fmod(counter, 4294967291) -- 2^32 - 5: Prime (and different from the prime in the loop)
end

--------------------------------------------------------------------------------
function IntToStrThousands (value)

   local negative = value<0;
   if negative then value = -value; end;

   if value==0 then return ("0"); end;
   result = "";
   while value>0 do
      if (result~="") then result = ","..result; end;
      v3 = math.floor(value / 1000);
      if v3>0 then result = string.format ("%03d", value % 1000)..result;
      else         result = string.format ("%d", value % 1000)..result;
      end;
      value = v3;
   end;
   if negative then result = "-"..result; end;
   return result;
end;

--------------------------------------------------------------------------------
--------------------------------------------------------------------------------
--------------------------------------------------------------------------------
local cGOLD="ffd100"
local cSILVER="e6e6e6"
local cCOPPER="c8602c"

local GSC_3 = "|cff%s%d|cff000000.|cff%s%02d|cff000000.|cff%s%02d|r"
local GSC_2 = "|cff%s%d|cff000000.|cff%s%02d|r"
local GSC_1 = "|cff%s%d|r"

local iconpath   = "Interface\\MoneyFrame\\UI-"
local goldicon   = "%s|T"..iconpath.."GoldIcon:%d|t"
local silvericon = "%s|T"..iconpath.."SilverIcon:%d|t"
local coppericon = "%s|T"..iconpath.."CopperIcon:%d|t"
local sep        = " ";

--------------------------------------------------------------------------------
function MoneyString (money, graphic, shorten_threshold, iconheight)

   if not iconheight then iconheight = 0; end;
   money = math.floor(tonumber(money) or 0);
   
   local g = math.floor(money / 10000);
   local s = math.floor(money % 10000 / 100);
   local c = money % 100;

   if not graphic then
      if     g>0 then return GSC_3:format(cGOLD, g, cSILVER, s, cCOPPER, c)
      elseif s>0 then return GSC_2:format(cSILVER, s, cCOPPER, c)
      else            return GSC_1:format(cCOPPER, c)
   end
   else
      local shorten = shorten_threshold;
      if shorten then shorten = money>=shorten_threshold; end;
      if shorten then return goldicon:format(IntToStrThousands(g), iconheight);
      elseif g>0 then return goldicon:format(IntToStrThousands(g), iconheight)..sep..silvericon:format("%02d", iconheight):format(s)..sep..coppericon:format("%02d", iconheight):format(c)
      elseif s>0 then return silvericon:format("%d", iconheight):format(s)..sep..coppericon:format("%02d", iconheight):format(c)
      else                   return coppericon:format("%d", iconheight):format(c)
      end;
   end;
end;

--------------------------------------------------------------------------------
function MoneyStringRaw (money, shorten_threshold)

   money = math.floor(tonumber(money) or 0);

   local g = math.floor(money / 10000);
   local s = math.floor(money % 10000 / 100);
   local c = money % 100;
   local z;

   if shorten_threshold and (money>=shorten_threshold) then
      return IntToStrThousands(g).."g";
   end;

   z = "";
   if g>0 then
      z = z..IntToStrThousands(g).."g ";
   end;
   if (g>0) or (s>0) then
      z = z..string.format("%02d", s).."s ";
   end;
   z = z..string.format("%02d", c).."c";
   return z;
end;

